{% extends "layout.html" %}
{% block title %}Update software profile{% endblock %}
{% block head %}
  {{ super() }}
    <script src="{{ url_for('static', filename='js/ace/ace-uncompressed.js') }}" type="text/javascript" charset="utf-8"></script>
    <script src="{{ url_for('static', filename='js/ace/theme-crimson_editor.js') }}" type="text/javascript" charset="utf-8"></script>
    <script src="{{ url_for('static', filename='js/ace/mode-buildout.js') }}" type="text/javascript" charset="utf-8"></script>
  <script src="{{ url_for('static', filename='js/scripts/editor.js') }}" type="text/javascript" charset="utf-8"></script>
{% endblock %}
{% block body %}
<form method=post class=add-entry>
    <dl>
        <dd><h2>Edit software profile <a href='#' id="editOption" rel="tooltip" title='Show more option'>[More]</a>:</h2></dd>
        <dd><div class='md5sum' id='md5sum'></div></dd>
        <dd>
           <div class="main_content">
<pre id="editor"></pre>
            </div>
            <input type="hidden" name="profile" id="profile" value="{{ profile|safe }}" />
	    <input type="hidden" name="workdir" id="workdir" value="{{workDir}}"/>
        </dd>
        <dd><input type=submit value=Save id="save" class="button"></dd>
    </dl>
</form>
<div id="tooltip-editOption" style="display:none">
  <span class="list">MD5 SUM for the current file</span>
    <div style="margin-top:3px; margin-bottom:5px;border-bottom: 1px dashed #666666; heigth:1px"></div>
    <a id='getmd5' href="#">Get or Update md5sum</a>
    <br/><span class="list">Add Project to Develop</span><br/>
    <div style="margin-top:3px;border-bottom: 1px dashed #666666; heigth:1px"></div>
    <ul id="plist">
    {% for name in projectList%}
  <li><input type="checkbox" name="develop" value="{{name}}" id="{{name}}">
  <label>{{name}}</label></li>
    {% endfor %}
    </ul>
    <br/>
    <a href="#" id="adddevelop" class="lshare">Add to profile</a>
</div>
{% endblock %}

