#tabContaier{
	background: #e4e4e4;
	padding:3px;
	position:relative;
	width:757px;
	font-size: 14px;
  border-radius: 4px 4px 0 0;
}

#tabContaier textarea {
	width:702px;
}
#tabContaier > ul{
	overflow:hidden;
	height:34px;
	position:absolute;
	z-index:100;
}
#tabContaier > ul > li{
	float:left;
	list-style:none;
}
#tabContaier > ul > li a{
	background:#e4e4e4;
	border-left:1px solid #fcfcfc;
	color:#666;
	cursor:pointer;
	display:block;
	height:34px;
	line-height:34px;
	padding:0 30px;
	text-decoration:none;
	color: #737373;
	text-shadow: 0px 1px #FFF;
	font-size: 17px;
}
#tabContaier > ul > li a:hover{
	background:#eee;
}
#tabContaier > ul > li a.active{
	background:#fbfbfb;
	border:1px solid #fff;	
  border-top:0;
	border-right:0;  
	color:#333;
}
#tabContaier > ul > li:first-child a{border-left:0}
.tabDetails{
	background:#fbfbfb;
	border-top: none;
	margin:34px 0 0;
}
.tabContents{
	padding:20px
}
.tabContents p{
	padding:0 0 10px;
} 
